@@ -4,34 +4,28 @@ package Net::UPnP;
 # UPnP
 #-----------------------------------------------------------------
 
-use version;
+#require 5.005;
+
 use strict;
 use warnings;
 
+use Socket;
+
 use vars qw($VERSION $DEBUG $SSDP_ADDR $SSDP_PORT);
 
-
-$VERSION  = '1.4.5';
+$VERSION  = '1.1';
 $DEBUG = 0;
 
 $SSDP_ADDR = '239.255.255.250';
 $SSDP_PORT = 1900;
 
-#------------------------------
-# id
-#------------------------------
-
-sub SetDebug() {
-	$DEBUG = $_[0];
-}
-
 1;
 
 __END__
 
 =head1 NAME
 
-Net::UPnP - Perl extension for UPnP
+UPnP - Perl extension for UPnP
 
 =head1 SYNOPSIS
 
