@@ -84,7 +84,7 @@ sub browse {
 			'SortCriteria' => $args{SortCriteria},
 		);
 	
-	$condir_service->postaction("Browse", \%req_arg);
+	$condir_service->postcontrol("Browse", \%req_arg);
 }
 
 sub browsedirectchildren {
@@ -149,9 +149,6 @@ sub getcontentlist {
 		$content,
 		$container,
 		$item,
-		$numberReturned,
-		$requestedCount,
-		$totalMatches
 	);
 	
 	@content_list = ();
@@ -162,37 +159,8 @@ sub getcontentlist {
 			RequestedCount => $args{RequestedCount},
 			SortCriteria => $args{SortCriteria}
 			);
-	$numberReturned = 0;
-	if ($action_res->getstatuscode() == 200) {
-		$arg_list = $action_res->getargumentlist();
-		$numberReturned = int($arg_list->{'NumberReturned'});
-	}
-	if ($numberReturned <= 0) {
-		$action_res = $this-> browsemetadata(
-				ObjectID => $args{ObjectID},
-				Filter => $args{Filter},
-				StartingIndex => $args{StartingIndex},
-				RequestedCount => $args{RequestedCount},
-				SortCriteria => $args{SortCriteria}
-			);
-		$requestedCount = 999;
-		if ($action_res->getstatuscode() == 200) {
-			$arg_list = $action_res->getargumentlist();
-			$totalMatches = int($arg_list->{'TotalMatches'});
-			if (1 < $totalMatches) {
-				$requestedCount = $totalMatches;
-			}
-		}
-		$action_res = $this->browsedirectchildren(
-				ObjectID => $args{ObjectID},
-				Filter => $args{Filter},
-				StartingIndex => $args{StartingIndex},
-				RequestedCount => $requestedCount,
-				SortCriteria => $args{SortCriteria}
-			);
-		if ($action_res->getstatuscode() != 200) {
-			return @content_list;
-		}
+	if ($action_res->getstatuscode() != 200) {
+		return @content_list;
 	}
 	$arg_list = $action_res->getargumentlist();
 	unless ($arg_list->{'Result'}) {
@@ -244,31 +212,6 @@ sub getcontentlist {
 	@content_list;
 }
 
-#------------------------------
-# getsystemupdateid
-#------------------------------
-
-sub getsystemupdateid {
-	my($this) = shift;
-
-	my (
-		$dev,
-		$condir_service,
-		$query_res,
-	);
-	
-	$dev = $this->getdevice();
-	$condir_service = $dev->getservicebyname($Net::UPnP::AV::MediaServer::CONTENTDIRECTORY_SERVICE_TYPE);
-	
-	$query_res = $condir_service->postquery("SystemUpdateID");
-
-	if ($query_res->getstatuscode() != 200) {
-		return "";
-	}
-	
-	return $query_res->getvalue();
-}
-
 1;
 
 __END__
