@@ -45,6 +45,7 @@ sub search {
 		$dev_addr,
 		$dev_port,
 		$dev_path,
+		$dev_friendly_name,
 		$http_req,
 		$post_res,
 		$post_content,
@@ -86,15 +87,12 @@ SSDP_SEARCH_MSG
 			next;
 		}		
 		$dev_location = $1;
-		print "dev_location=$dev_location\n" if ($Net::UPnP::DEBUG);
-                unless ($dev_location =~ m{http://([0-9a-z.-]+)(?::(\d+))?/(.*)}i) {
-                        print "bad dev_location: $dev_location\n" if ($Net::UPnP::DEBUG);
+		unless ($dev_location =~ m/http:\/\/([0-9a-z.]+)[:]*([0-9]*)\/(.*)/i) {
 			next;
 		}
 		$dev_addr = $1;
-		$dev_port = $2 || 80;
+		$dev_port = $2;
 		$dev_path = '/' . $3;
-		print "dev_addr=$dev_addr dev_port=$dev_port dev_path=$dev_path\n" if ($Net::UPnP::DEBUG);
 		
 		$http_req = Net::UPnP::HTTP->new();
 		$post_res = $http_req->post($dev_addr, $dev_port, "GET", $dev_path, "", "");
@@ -112,6 +110,7 @@ SSDP_SEARCH_MSG
 		$dev->setdescription($post_content);
 	
 		if ($Net::UPnP::DEBUG) {
+	 		print "friendlyName = $dev_friendly_name\n";
 	 		print "ssdp = $ssdp_res_msg\n";
 	 		print "description = $post_content\n";
 	 	}
