@@ -57,17 +57,6 @@ sub setdescription() {
 
 sub getdescription() {
 	my($this) = shift;
-	my %args = (
-		name => undef,	
-		@_,
-	);
-	if ($args{name}) {
-		# Thanks for Tim Engler <engler at gmail.com> (2009/06/10)
-		unless ($this->{$Net::UPnP::Device::_DESCRIPTION} =~ m/<$args{name}>(.*?)<\/$args{name}>/i) {
-			return '';
-		}
-	 	return $1;
-	}
 	$this->{$Net::UPnP::Device::_DESCRIPTION};
  }
 
@@ -151,7 +140,10 @@ sub getlocation() {
 
 sub getdevicetype() {
 	my($this) = shift;
-	$this->getdescription(name => 'deviceType');
+	unless ($this->{$Net::UPnP::Device::_DESCRIPTION} =~ m/<deviceType>(.*)<\/deviceType>/i) {
+		return '';
+	}
+ 	return $1;
  }
 
 #------------------------------
@@ -160,70 +152,10 @@ sub getdevicetype() {
 
 sub getfriendlyname() {
 	my($this) = shift;
-	$this->getdescription(name => 'friendlyName');
- }
-
-#------------------------------
-# getmanufacturer
-#------------------------------
-
-sub getmanufacturer() {
-	my($this) = shift;
-	$this->getdescription(name => 'manufacturer');
- }
-
-#------------------------------
-# getmanufacturerurl
-#------------------------------
-
-sub getmanufacturerurl() {
-	my($this) = shift;
-	$this->getdescription(name => 'manufacturerURL');
- }
-
-#------------------------------
-# getmodeldescription
-#------------------------------
-
-sub getmodeldescription() {
-	my($this) = shift;
-	$this->getdescription(name => 'modelDescription');
- }
-
-#------------------------------
-# getmodelname
-#------------------------------
-
-sub getmodelname() {
-	my($this) = shift;
-	$this->getdescription(name => 'modelName');
- }
-
-#------------------------------
-# getmodelnumber
-#------------------------------
-
-sub getmodelnumber() {
-	my($this) = shift;
-	$this->getdescription(name => 'modelNumber');
- }
-
-#------------------------------
-# getmodelurl
-#------------------------------
-
-sub getmodelurl() {
-	my($this) = shift;
-	$this->getdescription(name => 'modelURL');
- }
-
-#------------------------------
-# getserialnumber
-#------------------------------
-
-sub getserialnumber() {
-	my($this) = shift;
-	$this->getdescription(name => 'serialNumber');
+	unless ($this->{$Net::UPnP::Device::_DESCRIPTION} =~ m/<friendlyName>(.*)<\/friendlyName>/i) {
+		return '';
+	}
+ 	return $1;
  }
 
 #------------------------------
@@ -232,16 +164,10 @@ sub getserialnumber() {
 
 sub getudn() {
 	my($this) = shift;
-	$this->getdescription(name => 'UDN');
- }
-
-#------------------------------
-# getupc
-#------------------------------
-
-sub getupc() {
-	my($this) = shift;
-	$this->getdescription(name => 'UPC');
+	unless ($this->{$Net::UPnP::Device::_DESCRIPTION} =~ m/<UDN>(.*)<\/UDN>/i) {
+		return '';
+	}
+ 	return $1;
  }
 
 #------------------------------
@@ -250,7 +176,10 @@ sub getupc() {
 
 sub geturlbase() {
 	my($this) = shift;
-	$this->getdescription(name => 'URLBase');
+	unless ($this->{$Net::UPnP::Device::_DESCRIPTION} =~ m/<URLBase>(.*)<\/URLBase>/i) {
+		return '';
+	}
+ 	return $1;
  }
 
 1;
@@ -286,6 +215,7 @@ Net::UPnP::Device - Perl extension for UPnP.
         %action_in_arg = (
                 'ObjectID' => 0,
                 'BrowseFlag' => 'BrowseDirectChildren',
+
                 'Filter' => '*',
                 'StartingIndex' => 0,
                 'RequestedCount' => 0,
@@ -316,13 +246,9 @@ The package is used a object of UPnP device.
 
 =item B<getdescription> - get the description.
 
-    $description = $dev->getdescription(
-    	                        name => $name # undef
-                             );
+    $description = $dev->getdescription();
 
-Get the device description of the SSDP location header. 
-	
-The function returns the all description when the name parameter is not specified, otherwise return a value the specified name.
+Get the device description from the SSDP location header.
 
 =item B<getdevicetype> - get the device type.
 
@@ -336,59 +262,11 @@ Get the device type from the device description.
 
 Get the friendly name from the device description.
 
-=item B<getmanufacturer> - get the manufacturer.
-
-    $manufacturer = $dev->getmanufacturer();
-
-Get the manufacturer name from the device description.
-
-=item B<getmanufacturerrul> - get the manufacturer url.
-
-    $manufacturer_url = $dev->getmanufacturerrul();
-
-Get the manufacturer url from the device description.
-
-=item B<getmodeldescription> - get the model description.
-
-    $model_description = $dev->getmodeldescription();
-
-Get the model description from the device description.
-
-=item B<getmodelname> - get the model name.
-
-    $model_name = $dev->getmodelname();
-
-Get the model name from the device description.
-
-=item B<getmodelnumber> - get the model number.
-
-    $model_number = $dev->getmodelnumber();
-
-Get the model number from the device description.
-
-=item B<getmodelurl> - get the model url.
-
-    $model_url = $dev->getmodelurl();
-
-Get the model url from the device description.
-
-=item B<getserialnumber> - get the serialnumber.
-
-    $serialnumber = $dev->getserialnumber();
-
-Get the model description from the device description.
-
-=item B<getudn> - get the device UDN.
+=item B<getudn> - get the device type.
 
     $udn = $dev->getudn();
 
-Get the UDN from the device description.
-
-=item B<getupc> - get the device UPC.
-
-    $upc = $dev->getupc();
-
-Get the UPC from the device description.
+Get the udn from the device description.
 
 =item B<getservicelist> - get the device type.
 
